#
# spec file for package synergy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# since Nov 2017 synergy FOSS core is called synergy-core
%define synergy synergy-core
Name:           synergy
Version:        1.9.1
Release:        5.1
Summary:        Mouse, keyboard and clipboard sharing utility
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
URL:            http://synergy-project.org/
Source0:        https://github.com/symless/synergy-core/archive/v%{version}-stable.tar.gz
Source2:        qsynergy.desktop
Source3:        qsynergy.png
Source4:        synergys.socket
Source5:        synergys.service
# The test suite uses an incompatible Apache-2.0 license
# https://build.opensuse.org/request/show/616454
Patch1:         legal-disable-tests.patch
# PATCH-FIX-UPSTREAM add-support-for-latin-s-and-t-with-comma-below.patch
Patch2:         add-support-for-latin-s-and-t-with-comma-below.patch
# PATCH-FIX-UPSTREAM qt5_fixes.patch
Patch3:         qt5_fixes.patch
# patches from Gentoo (taken from Mageia)
Patch11:        synergy-1.5.0-pthread.patch
Patch14:        synergy-1.5.0-disable-version-check.patch
BuildRequires:  avahi-devel
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
BuildRequires:  mDNSResponder-devel
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xtst)
Provides:       %{synergy} = %{version}
Obsoletes:      %{synergy} < %{version}
%{?systemd_ordering}
%if 0%{?suse_version} != 1315
BuildRequires:  libcryptopp-devel
Requires(pre):  %fillup_prereq
Provides:       synergy-plus = %{version}
Obsoletes:      synergy-plus < %{version}
%endif

%description
Synergy lets you easily share a single mouse and keyboard between
multiple computers with different operating systems, each with its own
display, without special hardware.  It's intended for users with
multiple computers on their desk since each system uses its own
display.

Redirecting the mouse and keyboard is as simple as moving the mouse off
the edge of your screen.  Synergy also merges the clipboards of all the
systems into one, allowing cut-and-paste between systems. Furthermore,
it synchronizes screen savers so they all start and stop together and,
if screen locking is enabled, only one screen requires a password to
unlock them all.

%package -n qsynergy
Summary:        Qt GUI for easily configuring Synergy2
Group:          Productivity/Networking/Other
Requires:       synergy = %{version}

%description -n qsynergy
QSynergy is a comprehensive and easy to use graphical front end for Synergy.
Synergy lets a user control more than one computer with a single mouse and
keyboard.

%prep
%autosetup -p1 -n %{synergy}-%{version}-stable

cp %{SOURCE2} .

%build
export SYNERGY_VERSION_STAGE="release"
%cmake
make VERBOSE=1 %{?_smp_mflags}
# leave the build subfolder
cd ..

%install
chmod -x ChangeLog
install -D build/bin/synergyd "%{buildroot}%{_bindir}/synergyd"
install -D build/bin/synergyc "%{buildroot}%{_bindir}/synergyc"
install -D build/bin/synergys "%{buildroot}%{_bindir}/synergys"
install -D build/bin/syntool  "%{buildroot}%{_bindir}/syntool"
install -D -m0644 doc/synergy.conf.example "%{buildroot}%{_sysconfdir}/synergy.conf"
install -D -m0644 doc/synergyc.man "%{buildroot}%{_mandir}/man1/synergyc.1"
install -D -m0644 doc/synergys.man "%{buildroot}%{_mandir}/man1/synergys.1"

# Unit file
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sbindir}
install -p -m 644 "%{SOURCE4}" %{buildroot}%{_unitdir}
install -p -m 644 "%{SOURCE5}" %{buildroot}%{_unitdir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcsynergys

# GUI package
install -Dm 0755 build/bin/%{name} %{buildroot}%{_bindir}/q%{name}
%suse_update_desktop_file -i q%{name}

%post
%fillup_only
%desktop_database_post
%service_add_post synergys.service synergys.socket

%postun
%desktop_database_postun
%service_del_postun synergys.service synergys.socket

%pre
%service_add_pre synergys.service synergys.socket

%preun
%service_del_preun synergys.service synergys.socket

%files
%doc ChangeLog doc/synergy.conf*
%license LICENSE
%config(noreplace) %{_sysconfdir}/synergy.conf
%{_bindir}/synergyc
%{_bindir}/synergys
%{_bindir}/synergyd
%{_bindir}/syntool
%{_mandir}/man1/synergys.1%{?ext_man}
%{_mandir}/man1/synergyc.1%{?ext_man}
%{_unitdir}/synergys.service
%{_unitdir}/synergys.socket
%{_sbindir}/rcsynergys

%files -n qsynergy
%license LICENSE
%{_bindir}/q%{name}
%{_datadir}/applications/q%{name}.desktop
%{_datadir}/pixmaps/q%{name}.png

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * synergys.service
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Fri Jul 26 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Thu Nov  8 2018 sflees@suse.de
- Disable build and use of gmock due to its incompatible apache-2.0
  license https://build.opensuse.org/request/show/616454
  legal-disable-tests.patch
- No need to sed out setting the CXX flags
- spec cleaner run
* Wed Jun 13 2018 oholecek@suse.com
- Fix source download URL
  - s/synergy/synergy-core/
* Tue Jun 12 2018 oholecek@suse.com
- Update to 1.9.1
  * Fixed issue with screen resolution detection during sleep on macOS
  * Updated OpenSSL to v1.0.2o
- Update to 1.9.0
  * Ported UI to Qt 5
  * Moved GUI build script to CMake
  * Build with MSVC 2015
  * Removal of deprecated 'hm.sh' script and toolchains
- Add Provides and Obsoletes synergy-core (new upstream name)
- Remove patch 0001-OpenSSL-1.1.0-build-fix.patch as now upstream
- Add patch qt5_fixes.patch to fix building under QT5.11
- Refresh patch synergy-1.5.0-pthread.patch
- Refresh patch synergy-1.5.0-disable-version-check.patch
* Sat Feb 24 2018 robert.munteanu@gmail.com
- Add add-support-for-latin-s-and-t-with-comma-below.patch,
  submitted upstream at https://github.com/symless/synergy-core/pull/6261
* Tue Feb 20 2018 aloisio@gmx.com
- Switched build to Qt5
- Enabled PIE
* Wed Jan  3 2018 oholecek@suse.com
- Add patch 0001-OpenSSL-1.1.0-build-fix.patch taken from upstream
* Wed May  3 2017 werner@suse.de
- Update to 1.8.8
  * Bug #5196 - Some keys on Korean and Japanese keyboards have the same keycode
  * Bug #5578 - Pressing Hangul key results in alt+'a'
  * Bug #5785 - Can't switch screens when cursor is in a corner
  * Bug #3992 - macOS: Dragging is broken in Unity 3D
  * Bug #5075 - macOS: Build fails on macOS 10.9 due to unknown compiler flag
  * Bug #5809 - macOS: No version number is shown in the App Info dialog
  * Bug #3197 - Linux: switchDoubleTap option is not working
  * Bug #4477 - Linux: Mouse buttons higher than id 10 result in crash
  * Bug #5832 - Linux: Screen size misdetected on multi-monitor display
  * Enhancement #4504 - Improved Korean language description
  * Enhancement #5525 - Added support for precise screen positioning in config file
  * Enhancement #4290 - Windows: Removed annoying alt+print screen functionality
- Remove patch 0001-XRandR-fix-screen-size-calculation.patch
  as now upstream
* Mon Feb  6 2017 martin.wilck@suse.com
- Fix screen size calculation with XRandR enabled (boo#1023635)
  * Added 0001-XRandR-fix-screen-size-calculation.patch
* Tue Jan 31 2017 oholecek@suse.com
- Remove source URL synergy prefix
* Mon Jan 23 2017 sflees@suse.de
- Update to 1.8.7
  - 1.8.7 changes
  * Bug #5784 - Edition changes when reopening GUI
  - 1.8.6 changes
  * Bug #5186 - Cursor stuck on client when using multi-DPI server
  * Bug #5722 - Malformed serial key in registry will crash GUI on startup
  * Bug #5752 - Tab order is incorrect on Settings dialog
  - 1.8.5 changes
  * Bug #5680 - Server crashes when disconnecting SSL clients
  * Feature #5707 - User upgrade statistics
  - 1.8.4 changes
  * Bug #4420 When XRandR adds a screen, it is inaccessible
  * Bug #5603 Activation notification depends on existence of /etc/os-release
  * Bug #5624 Update notification sometimes requests a downgrade
  * Bug #5329 Current date is shown for build date in the about dialog
  * Bug #5640 Synergy branding is inconsistent across platforms
  * Enhancement #5617 Remove redundant plugin infrastructure
  * Enhancement #5627 Move SSL certificate generation to main window
  * Enhancement #5628 Move SSL implementation into core binary
  * Enhancement #5629 Move activation from wizard into new dialog window
  - 1.8.3 changes
  * Bug #4740 - Linux client crashes with "Assertion '!m_open' failed"
  * Bug #4879 - Memory leak caused by IpcReader
  * Bug #5373 - Tab behaves like shift tab on client
  * Bug #5502 - Copy and paste from server to client doesn't work
  * Enhancement #123 - Option to disable clipboard sharing
* Fri Aug 19 2016 oholecek@suse.com
- Remove support for old versions
- Remove hack to disable tests and use bundled gmock
* Fri Aug 19 2016 oholecek@suse.com
- Remove gtest-devel dependency and use bundled one
* Thu Aug 18 2016 oholecek@suse.com
- Update to 1.8.2
  * Bug #3044 - Unable to drag-select in MS Office
  * Bug #4768 - Copy paste causes 'server is dead' error on switching
  * Bug #4792 - Server logging crashes when switching with clipboard data
  * Bug #2975 - Middle click does not close Chrome tab on Mac client
  * Bug #5087 - Linux client fails to start due to invalid cursor size
  * Bug #5471 - Serial key textbox on activation screen overflows on Mac
  * Bug #4836 - Stop button resets to Start when settings dialog canceled
  * Enhancement #5277 - Auto restart service when synwinhk.dll fails on Windows
  * Enhancement #4913 - Future-proof GUI login by using newer auth URL
  * Enhancement #4922 - Add --enable-crypto argument to help text
  * Enhancement #5299 - High resolution App icon on Mac
  * Enhancement #4894 - Improve grammar in connection notification dialog
- Drop patch synergy-1.5.0-test.patch
- Remove src/test/CMakeLists.txt to disable tests building
* Fri Apr  1 2016 oholecek@suse.com
- update source URL as noted in original https://github.com/synergy/synergy/
* Mon Mar 21 2016 oholecek@suse.com
- Update to 1.7.6
  * Bug #451 - Fast cursor on any client with Mac server
  * Bug #5041 - Copying from the Chrome web browser doesn't work
  * Bug #4735 - Clipboard doesn't work from client to server
  * Bug #2909 - Clipboard copies only plaintext between Mac and Windows
  * Bug #4353 - Large clipboard causes crash
  * Bug #3774 - Missing MinGW dependencies after install on Windows
  * Bug #4723 - Waiting for active desktop result freezes Windows service
- Drop patches fixing bug #4735:
  add-retry-to-condvarbase-wait-make-sure-stopwatch-is.patch
  fix-bug-4735-don-t-leave-until-fillclipboard-s-all.patch
  properly-lock-condvar-add-timeout-condition-to-prevent.patch
* Sat Jan 16 2016 mimi.vx@gmail.com
- update to 1.7.5
  * Bug #5030 - Display scaling breaks edge detection on Windows
  * Bug #5064 - Compile fails on Mac OS X 10.11 (unused typedef)
* Sun Sep 27 2015 sleep_walker@opensuse.org
- prevent random hangs (bnc#944514, synergy #4735)
  add-retry-to-condvarbase-wait-make-sure-stopwatch-is.patch
* Fri Sep  4 2015 sleep_walker@opensuse.org
- make clipboard and selection work reliably again
  (bnc#944514, synergy #4735)
  fix-bug-4735-don-t-leave-until-fillclipboard-s-all.patch
  properly-lock-condvar-add-timeout-condition-to-prevent.patch
* Thu Sep  3 2015 mpluskal@suse.com
- Update to 1.7.4
  * Bug #4721 - High CPU usage for Windows service
  * Bug #4750 - SSL connect error 'passive ssl error limit'
  * Bug #4584 - Drag and drop with SSL causes crash
  * Bug #4749 - Clipboard thread race condition causes assertion
    failure
  * Bug #4720 - Plugin download shows 'Could not get Linux package
    type' error
  * Bug #4712 - Unable to send clipboard with size above 1KB when
    using SSL
  * Bug #4642 - Connecting causes SSL23_GET_SERVER_HELLO error
  * Bug #4690 - Log line 'activeDesktop' does not use logging
    system
  * Bug #4866 - Wrong ns plugin version can be loaded
  * Enhancement #4901 - Auto restart when running from GUI in
    desktop mode
  * Enhancement #4845 - Add timestamp to log output
- Enable building for SLE-12
* Thu Aug 13 2015 mpluskal@suse.com
- Also package syntool
* Mon Aug 10 2015 mpluskal@suse.com
- Update to 1.7.3
  * Bug #4565 - Incorrect plugin downloads on Debian and Mint
  * Bug #4677 - Windows service log file grows to very large size
  * Bug #4651 - High logging rate causes Windows service to crash
  * Bug #4650 - SSL error log message repeats excessively and
    freezes cursor
  * Bug #4624 - Runaway logging causes GUI to freeze
  * Bug #4617 - Windows service randomly stops after 'ssl
    handshake failure' error
  * Bug #4601 - Large clipboard data with SSL causes 'protocol is
    shutdown' error
  * Bug #4593 - Locking Windows server causes SSL_ERROR_SSL to
    repeat
  * Bug #4577 - Memory leak in GUI on Windows caused by logging
  * Bug #4538 - Windows service crashes intermittently with no
    error
  * Bug #4341 - GUI freezes on first load when reading log
  * Bug #4566 - Client or server crashes with 'ssl handshake
    failure' error
  * Bug #4706 - Installer is not output to build config dir
    on Windows
  * Bug #4704 - Plugin 'ns' release build is overwritten with
    debug version on Linux
  * Bug #4703 - Plugins are not built to config directory on Mac
  * Bug #4697 - Timing can allow an SSL socket to be used after
    cleanup call
  * Enhancement #4661 - Log error but do not crash when failing
    to load plugins
  * Enhancement #4708 - Download ns plugin for specific Mac
    versions
  * Enhancement #4587 - Include OpenSSL binaries in source for
    easier building
  * Enhancement #4695 - Automatically upload plugins as
    Buildbot step
  * See attached Changelog for detailed list of changes
- Drop no longer needed synergy-1.5.0-crytopp.patch
* Thu Dec  4 2014 tchvatal@suse.com
- Version bump to 1.6.2:
  * Bug #4227 - Helper tool crashes when service checks elevation state
  * Bug #4091 - Zeroconf on server advertises bogus IP address
  * Bug #4249 - Drag file causes client crash on Mac (10.10)
  * Enhancement #4196 - Optional Bonjour requirement for Windows
  * Enhancement #4235 - Automatic Bonjour download and install
  * Enhancement #4218 - Auto-config available servers combo box
  * Enhancement #4230 - More user friendly dialog when client is detected
  * Enhancement #4240 - Minimize auto config message box usage
  * Enhancement #4247 - Firewall exception for GUI (needed for Bonjour)
  * Enhancement #4242 - Consistent naming for auto config feature
  * Bug #4002 - Carbon loop not ready within 5 sec
  * Bug #4191 - Accessibility helper tool crashes
  * Bug #4149 - Mac 10.9.5 or 10.10 gatekeeper blocks Synergy
  * Bug #4139 - Exception thrown when ProcessIdToSessionId() fails
  * Bug #4055 - Shift keys are not sent to clients (Win 8.1 server)
  * Bug #4021 - Copy & paste not working for EFL applications
  * Bug #3749 - Linux Chrome hover doesn't work
  * Bug #4128 - Daemon logging not written with "log to file"
  * Enhancement #4122 - Enable drag and drop by default
  * Enhancement #4158 - Build for Mac OS X 10.10
  * Enhancement #4130 - Auto elevate for Windows UAC and screen lock
  * Enhancement #4126 - 64-bit support for OS X
  * Enhancement #4141 - DMRM message support for μSynergy
  * Enhancement #4124 - More robust argument parsing
  * Feature #65 - Auto config feature using Zeroconf/Bonjour
  * Bug #3307 - Configuration file paths containing spaces don't work
  * Bug #3404 - Log path needs to be in quotes on windows
  * Bug #3996 - Installer fails when Windows Firewall is disabled
- Remove patch done by upstream:
  * synergy-1.5.0-CSocketMultiplexer.patch
  * synergy-efl.patch
- Refresh version check patch:
  * synergy-1.5.0-disable-version-check.patch
- Synergy service do not use forking mode and restart on fail
* Wed Jul  2 2014 tchvatal@suse.com
- Do not use werror and simplify cflags handling
* Wed Jul  2 2014 sleep_walker@suse.cz
- setting Source with URL
- changing to %%cmake macro and cleanup
* Tue Jul  1 2014 sleep_walker@suse.cz
- bump to 1.5.0
  Changes:
  1.5.0
  =====
  Bug #4060 - Key stuck down on Windows server
  Bug #4061 - Windows server repeats modifier keys
  1.4.18
  ======
  Bug #3980 - Shell extension DLL causes explorer.exe to crash
  Task #4049 - Correct code style in OSXKeyState compilation unit
  Task #4050 - Fix subversion issue tracker URL
  Task #4053 - Improve deb package quality
  Task #4054 - Improve rpm package quality
  1.4.17
  ======
  Bug #2836 - Unable to begin screen name or alias with numbers
  Bug #3796 - Some files being unintentionally dragged (including explorer.exe)
  Bug #3886 - Alias is allowed to match screen name
  Bug #3919 - RPM install fails on Fedora 20, failed dependencies: libcurl
  Bug #3921 - Error: synwinxt.dll outdated (upgrading from 1.4.15 to 1.4.16)
  Bug #3927 - Mavericks accessibility exception not working (when upgrading from
    1.4.15 to 1.4.16)
  Bug #3933 - Plus signs in the email address cause premium login to fail
  Bug #3939 - Compile fails on ARM (Raspberry Pi) because of cryptopp/Crypto++
    lib
  Bug #3947 - Conflicts when using yum localinstall on Fedora 20
  Bug #3959 - Premium title doesn't always show on first login
  Bug #3968 - GUI auto-hides on initial first install (with no config)
  Task #3936 - Change installer to WiX for improved file upgrade process
  Task #3950 - Poll modifier after key down on Mac OS X and log results
  Task #3951 - Clear filename stored in synwinxt on mouse up
  Task #3952 - Make Premium wizard page cleaner
  Task #3953 - Inherit XArch and XBase from std::exception
  Task #3954 - Make "lock to screen" log message go to NOTE level instead of
    DEBUG
  Task #3960 - Split CMSWindowsHookLibraryLoader into hook and shellex loaders
  Task #3961 - Remove Windows 95 support
  Task #3963 - Disable failing Linux unit/integ tests on Fedora 20 32-bit
    (valgrind SIGILL)
  Task #3964 - Make Premium login error more verbose
  Task #3969 - Merge String.cpp and StringUtil.cpp
  1.4.16
  ======
  Bug #3338 - Alt tab not working with Windows 8
  Bug #3642 - Failed to start server on Mac OS X 10.9 Mavericks, assistive
    devices problem
  Bug #3785 - Synwinxt.dll error opening file for writing during install of
    1.4.15
  Bug #3787 - Wont automatically load after login on OS X
  Bug #3788 - Configuration wizard: Premium login fails when behind a proxy
  Bug #3796 - Some files being unintentionally dragged (including explorer.exe)
  Bug #3799 - Synergy Client on Fedora crashes on drag/drop operations
  Bug #3818 - Client freezes on Mac OS 10.6.8
  Bug #3874 - Premium GUI login is case sensitive for email
  Bug #3911 - Drag and drop error on OS X 10.9 Mavericks
- added patches:
    synergy-efl.patch
    synergy-1.5.0-crytopp.patch
    synergy-1.5.0-CSocketMultiplexer.patch
    synergy-1.5.0-disable-version-check.patch
    synergy-1.5.0-pthread.patch
    synergy-1.5.0-test.patch
- removed patches:
    fix-for-efl.patch
    synergy-1.4.12-cryptopp.patch
    synergy-pthread.patch
* Tue Jul  1 2014 sleep_walker@suse.cz
- fix-for-efl.patch
  - reference:
  https://phab.enlightenment.org/T1335
  http://synergy-project.org/spit/issues/details/4091/
* Thu Oct 31 2013 tchvatal@suse.com
- Systemd should be dep only on 12.2+
* Thu Oct 31 2013 tchvatal@suse.com
- Add unitfiles so we can have service for server.
- Adds synergys.service and synergys.socket copied from archlinux.
* Sat Oct 26 2013 malcolmlewis@opensuse.org
- Add desktop file icon and modify desktop file.
- Add build requires for SLE target.
- Minor spec file changes for man pages.
* Sat Oct 26 2013 tchvatal@suse.com
- Version bump to 1.4.15:
  * fix broken GCM, CTR and OFB encryption
- Modify patch to apply:
  * synergy-1.4.12-cryptopp.patch
- Add new patch to link properly to pthread:
  * synergy-pthread.patch
* Fri Sep 13 2013 tchvatal@suse.com
- Format the deps, and sort them out.
* Fri Sep 13 2013 tchvatal@suse.com
- Fix the build again.
* Fri Sep 13 2013 tchvatal@suse.com
- Merge back qsynergy to have just one spec file.
* Fri Sep 13 2013 tchvatal@suse.com
- Move desktop file to the qsynergy part.
* Fri Sep 13 2013 tchvatal@suse.com
- Do not use init script, there is no damn reason to not launch it
  via gui or just set the command to autostart with login, which
  is more obvious than init script. Anyway it should be replaced
  by service file if someone wants to resurrect it.
  * Removes rcsynergy sysconfig.synergy
- Remove README.SUSE as it is pointless if we want to use it as
  upstream desired.
* Fri Sep 13 2013 tchvatal@suse.com
- Format spec file and use system cryptopp library.
  * add patch synergy-1.4.12-cryptopp.patch
* Mon Jun 17 2013 boris@steki.net
- updated to latest upstream version 1.4.12
- Bugfixes and new features
  * Bug #3565 - Encryption fails when typing fast (Invalid message from client)
  * Bug #3606 - GUI is elevated after setup
  * Bug #3572 - Mac caps lock causes disconnect
- Feature #12 - Encryption
- Feature #421 - Portable version
  * Bug #2855 - Mouse cursor remains hidden on Mac client (intermittently/randomly)
  * Bug #3281 - server start on OS X defaults to 'interactive'
  * Bug #3310 - Port in settings screen
* Tue Oct  9 2012 sleep_walker@suse.cz
- update to 1.4.10
- remove xinput2.patch which reached upstream
* Mon Jul  9 2012 werner@suse.de
- Update to beta 1.4.8
* Wed Sep 14 2011 adam@mizerski.pl
- build with %%optflags
* Mon Aug  1 2011 msvec@novell.com
- update to 1.3.7 (bug fix release)
- re-added man pages
* Sat Apr 16 2011 adam@mizerski.pl
- update to 1.3.6
- deleted all patches, because fixed upstream or no longer suitable
- obsoletes synergy-plus, because projects has merged.
* Wed Mar 10 2010 jeffm@suse.de
- Added firewall definitions for use with SuSEfirewall2
* Mon Nov 16 2009 hmuelle@novell.com
- Fixed issue with "perror was not declared in this scope" by
  "stdio.h" to two files:
  lib/arch/CArchNetworkBSD.cpp
  lib/arch/CArchDaemonUnix.cpp
* Wed May 13 2009 sbrabec@suse.cz
- Fixed intermittent delays (bnc#495388).
- synergy-1.3.1-64bit_bug.patch was not applied by mistake. Fixed.
* Fri Aug 15 2008 guru@unixtech.be
- use latest SVN trunk
- added patch to fix Java swing crashing bug (lp#207057, bnc#413716)
* Mon Jul 14 2008 pascal.bleser@opensuse.org
- merged patches from home:sbrabec/synergy
- openSUSE 11.0 builds
- cleaned up spec file
- added debuginfo support
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 sbrabec@suse.cz
- Updated to version 1.2.7.
* Wed Dec 21 2005 mmj@suse.de
- Notify about errors
* Mon Nov 14 2005 sbrabec@suse.cz
- Updated to version 1.2.6.
* Mon Aug  8 2005 sbrabec@suse.cz
- Updated to version 1.2.4.
* Mon Aug  1 2005 sbrabec@suse.cz
- Updated to version 1.2.3.
* Tue Apr 26 2005 sbrabec@suse.cz
- Do not build with -Werror.
* Mon Feb 14 2005 sbrabec@suse.cz
- Updated to version 1.2.2.
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 1.2.1.
* Fri Aug 27 2004 sbrabec@suse.cz
- Updated to version 1.0.15.
* Mon May 24 2004 ro@suse.de
- added return values to non-void functions
* Thu Feb  5 2004 sbrabec@suse.cz
- Updated to version 1.0.14.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Aug 11 2003 sbrabec@suse.cz
- Updated to version 1.0.12.
* Thu May 15 2003 sbrabec@suse.cz
- Added new SuSE package.
